==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+47"/>
        <source>Status Bar Font:</source>
        <translation>ステータスバーフォント:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>ステータスバー</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>座標表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>ステータスバー</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+53"/>
        <source>Status Bar Font:</source>
        <translation>ステータスバーフォント:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>ステータスバー</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>座標表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>マウス表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>選択表示</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>進捗表示</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Show status tips</source>
        <translation>ステータスにTips表示</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>ステータスバー</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>ステータスバー(&amp;S)</translation>
    </message>
</context>
</TS>
